@@ -5,7 +5,7 @@ use warnings;
 
 use Carp;
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 sub import {
 	my $class   = shift;
@@ -29,6 +29,7 @@ sub import {
 			name    => $name,
 			default => $opts{default} || 'default',
 			export  => $opts{export},
+			_local  => [],
 		};
 	} else {
 		my %opts    = @_;
@@ -82,7 +83,7 @@ sub current {
 	my $vals = $data->{_merged}->{$package->env} ||= +{
 		%{ $data->{common} },
 		%{ $data->{envs}->{$package->env} || {} },
-		(map { %$_ } @{ $data->{_local} || []}),
+		(map { %$_ } @{ $data->{_local} }),
 	};
 }
 
@@ -96,12 +97,11 @@ sub local {
 	not defined wantarray and croak "local returns guard object; Can't use in void context.";
 
 	my $data = _data($package);
-	$data->{_local} ||= [];
 	push @{ $data->{_local} }, \%hash;
 	undef $data->{_merged};
 
 	bless sub {
-		pop @{ $data->{_local} };
+		@{ $data->{_local} } = grep { $_ != \%hash } @{ $data->{_local} };
 		undef $data->{_merged};
 	}, 'Config::ENV::Local';
 }
